@@ -5,7 +5,6 @@ use Carp;
 use Moose;
 use Moose::Util::TypeConstraints;
 use YAML::XS;
-#use File::ShareDir::Install qw(postamble);
 use File::Share 'dist_dir';
 my $dir = dist_dir('Data-Pokemon-Go');
 
@@ -16,7 +15,7 @@ use Data::Pokemon::Go::Skill;
 my $skill = Data::Pokemon::Go::Skill->new();
 
 my $all = {};
-foreach my $region (qw|Kanto Johto Hoenn Alola|){
+foreach my $region (qw|Kanto Johto Hoenn Alola Sinnoh|){
     my $data = YAML::XS::LoadFile("$dir/$region.yaml");
     map{ $data->{$_}{'name'} = $_ } keys %$data;
     %$all = ( %$all, %$data );
